==> haskell-ansi-wl-pprint-1.0.2-230.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-wl-pprint
version:              1.0.2
visibility:           public
id:                   ansi-wl-pprint-1.0.2-7sOIeOs5AP2BbbQYEAm2uX
key:                  ansi-wl-pprint-1.0.2-7sOIeOs5AP2BbbQYEAm2uX
license:              BSD-3-Clause
maintainer:           Edward Kmett <ekmett@gmail.com>
author:               Daan Leijen, Max Bolingbroke
homepage:             http://github.com/ekmett/ansi-wl-pprint
synopsis:
    The Wadler/Leijen Pretty Printer for colored ANSI terminal output

description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf).
    It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.

category:             User Interfaces, Text
abi:                  9bdc63642683f507f963c135b3b6aef3
exposed:              True
exposed-modules:      Text.PrettyPrint.ANSI.Leijen
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ansi-wl-pprint-1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ansi-wl-pprint-1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ansi-wl-pprint-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-wl-pprint
hs-libraries:         HSansi-wl-pprint-1.0.2-7sOIeOs5AP2BbbQYEAm2uX
depends:
    base-4.18.2.1
    prettyprinter-compat-ansi-wl-pprint-1.0.2-J09lbNJGa1YGlSNL6jHLne

haddock-interfaces:
    /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-wl-pprint-1.0.2-234-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-wl-pprint
version:              1.0.2
visibility:           public
id:                   ansi-wl-pprint-1.0.2-6wF9D8KNkfn6IyWIcVecCI
key:                  ansi-wl-pprint-1.0.2-6wF9D8KNkfn6IyWIcVecCI
license:              BSD-3-Clause
maintainer:           Edward Kmett <ekmett@gmail.com>
author:               Daan Leijen, Max Bolingbroke
homepage:             http://github.com/ekmett/ansi-wl-pprint
synopsis:
    The Wadler/Leijen Pretty Printer for colored ANSI terminal output

description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf).
    It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.

category:             User Interfaces, Text
abi:                  34c585698935f7f1f3f436aa86e41d26
exposed:              True
exposed-modules:      Text.PrettyPrint.ANSI.Leijen
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ansi-wl-pprint-1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ansi-wl-pprint-1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ansi-wl-pprint-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-wl-pprint
hs-libraries:         HSansi-wl-pprint-1.0.2-6wF9D8KNkfn6IyWIcVecCI
depends:
    base-4.18.2.1
    prettyprinter-compat-ansi-wl-pprint-1.0.2-F7OtoluWLj7DbOIXyN1tRX

haddock-interfaces:
    /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
